AppsEvent

Enum AppsEvent 

pub enum AppsEvent {
    LicenseList {
        licenses: Vec<LicenseEntry>,
    },
    ProductInfoResponse {
        apps: HashMap<u32, AppInfoData>,
        packages: HashMap<u32, PackageInfoData>,
        unknown_apps: Vec<u32>,
        unknown_packages: Vec<u32>,
    },
    AccessTokensResponse {
        app_tokens: HashMap<u32, u64>,
        package_tokens: HashMap<u32, u64>,
        app_denied: Vec<u32>,
        package_denied: Vec<u32>,
    },
    ProductChangesResponse {
        current_change_number: u32,
        app_changes: Vec<AppChange>,
        package_changes: Vec<PackageChange>,
    },
    GCReceived(GCMessage),
    PlayingState {
        blocked: bool,
        playing_app: u32,
    },
}
App and game events.

Variants



LicenseList

Received licenses list.

Fields

licenses: Vec<LicenseEntry>


ProductInfoResponse

PICS product info response.

Fields

apps: HashMap<u32, AppInfoData>

App info data keyed by app ID.

packages: HashMap<u32, PackageInfoData>

Package info data keyed by package ID.

unknown_apps: Vec<u32>

Unknown/unavailable app IDs.

unknown_packages: Vec<u32>

Unknown/unavailable package IDs.



AccessTokensResponse

PICS access tokens response.

Fields

app_tokens: HashMap<u32, u64>

App access tokens keyed by app ID.

package_tokens: HashMap<u32, u64>

Package access tokens keyed by package ID.

app_denied: Vec<u32>

App IDs for which tokens were denied.

package_denied: Vec<u32>

Package IDs for which tokens were denied.



ProductChangesResponse

PICS product changes response.

Fields

current_change_number: u32

Current change number.

app_changes: Vec<AppChange>

App IDs that have changed.

package_changes: Vec<PackageChange>

Package IDs that have changed.



GCReceived(GCMessage)

Received a Game Coordinator message.



PlayingState

Playing session state changed.

Emitted when:

  • Right after logon, only if a game is being played elsewhere (blocked is true)
  • Whenever a game starts/stops being played on another session
  • Whenever you start/stop playing a game on this session

Fields

blocked: bool

True if playing is blocked because this account is playing a game in another location

playing_app: u32

The app ID currently being played (elsewhere if blocked, or by this session if not)