pub enum CSGOEvent {
Online(CsgoWelcome),
ClientHello(CsgoClientHello),
PlayersProfile(Vec<CsgoClientHello>),
PartyInvite {
inviter: SteamID,
lobby_id: u64,
},
PartySearchResults(Vec<CsgoPartyEntry>),
}Expand description
CS:GO specific events.
Variants
Online(CsgoWelcome)
CS:GO/CS2 Online event (Welcome message).
Emitted when the CS:GO Game Coordinator sends a welcome message, indicating the client is “online” in CS:GO/CS2.
ClientHello(CsgoClientHello)
CS:GO/CS2 Client Hello event.
Emitted when the CS:GO Game Coordinator sends a client hello response, containing player profile data (rank, level, commendations, etc.).
PlayersProfile(Vec<CsgoClientHello>)
CS:GO/CS2 Players Profile event.
Emitted when the CS:GO Game Coordinator sends a players profile
response, usually after a ClientRequestPlayersProfile message.
PartyInvite
Received a party invite.
PartySearchResults(Vec<CsgoPartyEntry>)
Received party search results.