pub struct GCJobManager { /* private fields */ }Expand description
Job manager for tracking pending GC requests.
Implementations
Sourceimpl GCJobManager
impl GCJobManager
Sourcepub fn with_timeout(default_timeout: Duration) -> Self
pub fn with_timeout(default_timeout: Duration) -> Self
Create a new GC job manager with a custom default timeout.
Sourcepub fn create_job(
&self,
appid: u32,
response_msg_type: u32,
) -> Receiver<GCJobResponse>
pub fn create_job( &self, appid: u32, response_msg_type: u32, ) -> Receiver<GCJobResponse>
Create a new job and return the response receiver.
The job is keyed by (appid, response_msg_type). When a GC message
matching this key arrives, the job will be completed.
Sourcepub fn create_job_with_timeout(
&self,
appid: u32,
response_msg_type: u32,
timeout: Duration,
) -> Receiver<GCJobResponse>
pub fn create_job_with_timeout( &self, appid: u32, response_msg_type: u32, timeout: Duration, ) -> Receiver<GCJobResponse>
Create a new job with a custom timeout.
Sourcepub fn try_complete(&self, appid: u32, msg_type: u32, payload: Vec<u8>) -> bool
pub fn try_complete(&self, appid: u32, msg_type: u32, payload: Vec<u8>) -> bool
Try to complete a job with a GC message.
Returns true if a matching job was found and completed.
Sourcepub fn cleanup_expired(&self)
pub fn cleanup_expired(&self)
Clean up expired jobs.
Sourcepub fn pending_count(&self) -> usize
pub fn pending_count(&self) -> usize
Get the number of pending jobs.