pub struct MockHttpClient { /* private fields */ }Expand description
Mock HTTP client for testing.
Queues responses to be returned by subsequent requests. Tracks all requests made for assertions.
Example
ⓘ
let mut mock = MockHttpClient::new();
mock.queue_response(HttpResponse::ok(r#"{"key": "value"}"#.as_bytes().to_vec()));
let response = mock.get("https://example.com").await?;
assert_eq!(response.status, 200);
// Verify the request was made
assert_eq!(mock.requests()[0].url, "https://example.com");Implementations
Sourceimpl MockHttpClient
impl MockHttpClient
Sourcepub fn queue_response(&self, response: HttpResponse)
pub fn queue_response(&self, response: HttpResponse)
Queue a response to be returned by the next request.
Sourcepub fn queue_error(&self, error: SteamError)
pub fn queue_error(&self, error: SteamError)
Queue an error to be returned by the next request.
Sourcepub fn queue_responses(&self, responses: Vec<HttpResponse>)
pub fn queue_responses(&self, responses: Vec<HttpResponse>)
Queue multiple responses.
Sourcepub fn requests(&self) -> Vec<MockRequest>
pub fn requests(&self) -> Vec<MockRequest>
Get all recorded requests.
Sourcepub fn last_request(&self) -> Option<MockRequest>
pub fn last_request(&self) -> Option<MockRequest>
Get the last request made.
Sourcepub fn clear_requests(&self)
pub fn clear_requests(&self)
Clear all recorded requests.
Sourcepub fn request_count(&self) -> usize
pub fn request_count(&self) -> usize
Get the number of requests made.