pub enum AuthEvent {
LoggedOn {
steam_id: SteamID,
},
LoggedOff {
result: EResult,
},
RefreshToken {
token: String,
account_name: String,
},
WebSession {
session_id: String,
cookies: Vec<String>,
},
GameConnectTokens {
tokens: Vec<Vec<u8>>,
},
}Expand description
Authentication events.
Variants
LoggedOn
Client logged on successfully.
LoggedOff
Client was logged off.
RefreshToken
Received a new refresh token (from password authentication). This can be saved and used for future logins without password.
WebSession
Web session established.
Emitted after successful login when web cookies are available. These cookies can be used to authenticate with Steam web APIs (e.g., steamcommunity.com, store.steampowered.com).
This event is emitted when:
- Login is successful and we have a refresh token that can generate web cookies
- The
get_web_session()method is called explicitly after login
Fields
Cookies in “name=value” format, suitable for HTTP Cookie headers.
GameConnectTokens
Received game connect tokens.